<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="cy_GB" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="103"/>
        <source>Help</source>
        <translation type="unfinished">Cymorth</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Draw vertical line at column</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Images (*.png *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="177"/>
        <source>New document</source>
        <translation>Dogfen newydd</translation>
    </message>
    <message>
        <location filename="tab.py" line="182"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Methu â dosrannu cynnwys y ffeil. Gwiriwch os ydych chi wedi arsefydlu&apos;r &lt;a href=&quot;%s&quot;&gt;modiwl hanfodol&lt;/a&gt;.</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="81"/>
        <source>File toolbar</source>
        <translation>Bar offer ffeiliau</translation>
    </message>
    <message>
        <location filename="window.py" line="83"/>
        <source>Edit toolbar</source>
        <translation>Bar offer golygu</translation>
    </message>
    <message>
        <location filename="window.py" line="85"/>
        <source>Search toolbar</source>
        <translation>Bar offer chwilio</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>New</source>
        <translation>Newydd</translation>
    </message>
    <message>
        <location filename="window.py" line="92"/>
        <source>Open</source>
        <translation>Agor</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Save</source>
        <translation>Cadw</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save as</source>
        <translation>Cadw fel</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Print</source>
        <translation>Argraffu</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Print preview</source>
        <translation>Rhagolwg argraffu</translation>
    </message>
    <message>
        <location filename="window.py" line="116"/>
        <source>View HTML code</source>
        <translation>Dangos cod HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Find text</source>
        <translation>Canfod testun</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Preview</source>
        <translation>Rhagolwg</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Rhagolwg byw</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Fullscreen mode</source>
        <translation>Modd sgrin llawn</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>Quit</source>
        <translation>Gadael</translation>
    </message>
    <message>
        <location filename="window.py" line="162"/>
        <source>Undo</source>
        <translation>Dadwneud</translation>
    </message>
    <message>
        <location filename="window.py" line="164"/>
        <source>Redo</source>
        <translation>Ailwneud</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Copy</source>
        <translation>Copi</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Cut</source>
        <translation>Torri</translation>
    </message>
    <message>
        <location filename="window.py" line="170"/>
        <source>Paste</source>
        <translation>Gludo</translation>
    </message>
    <message>
        <location filename="window.py" line="180"/>
        <source>Enable</source>
        <translation>Galluogi</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Set locale</source>
        <translation>Gosod iaith</translation>
    </message>
    <message>
        <location filename="window.py" line="182"/>
        <source>Use WebKit renderer</source>
        <translation>Defnyddio rendrydd Webkit</translation>
    </message>
    <message>
        <location filename="window.py" line="188"/>
        <source>Next</source>
        <translation>Nesaf</translation>
    </message>
    <message>
        <location filename="window.py" line="190"/>
        <source>Previous</source>
        <translation>Cynt</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Get help online</source>
        <translation>Cymorth ar-lein</translation>
    </message>
    <message>
        <location filename="window.py" line="196"/>
        <source>About ReText</source>
        <translation>Tua ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="199"/>
        <source>About Qt</source>
        <translation>Ynghylch Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Bold</source>
        <translation>Bras</translation>
    </message>
    <message>
        <location filename="window.py" line="216"/>
        <source>Italic</source>
        <translation>Italig</translation>
    </message>
    <message>
        <location filename="window.py" line="218"/>
        <source>Underline</source>
        <translation>Tanlinellu</translation>
    </message>
    <message>
        <location filename="window.py" line="230"/>
        <source>Symbols</source>
        <translation>Symbolau</translation>
    </message>
    <message>
        <location filename="window.py" line="235"/>
        <source>File</source>
        <translation>Ffeil</translation>
    </message>
    <message>
        <location filename="window.py" line="236"/>
        <source>Edit</source>
        <translation>Golygu</translation>
    </message>
    <message>
        <location filename="window.py" line="237"/>
        <source>Help</source>
        <translation>Cymorth</translation>
    </message>
    <message>
        <location filename="window.py" line="240"/>
        <source>Open recent</source>
        <translation>Agor diweddar</translation>
    </message>
    <message>
        <location filename="window.py" line="252"/>
        <source>Export</source>
        <translation>Allforio</translation>
    </message>
    <message>
        <location filename="window.py" line="273"/>
        <source>Spell check</source>
        <translation>Gwirio sillafu</translation>
    </message>
    <message>
        <location filename="window.py" line="284"/>
        <source>Formatting</source>
        <translation>Fformatio</translation>
    </message>
    <message>
        <location filename="window.py" line="321"/>
        <source>Search</source>
        <translation>Chwilio</translation>
    </message>
    <message>
        <location filename="window.py" line="323"/>
        <source>Case sensitively</source>
        <translation>Gan cas</translation>
    </message>
    <message>
        <location filename="window.py" line="458"/>
        <source>New document</source>
        <translation>Dogfen newydd</translation>
    </message>
    <message>
        <location filename="window.py" line="622"/>
        <source>Please, save the file somewhere.</source>
        <translation>Cadwch y ffeil i leoliad arall.</translation>
    </message>
    <message>
        <location filename="window.py" line="187"/>
        <source>Show directory</source>
        <translation>Dangos cyfeiriadur</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Select one or several files to open</source>
        <translation>Dewis un neu sawl ffeil i&apos;w hagor</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Supported files</source>
        <translation>Ffeiliau a gynhaliwyd</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>All files (*)</source>
        <translation>Pob ffeil (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="797"/>
        <source>Plain text (*.txt)</source>
        <translation>Testun plaen (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="800"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s ffeil</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>Save file</source>
        <translation>Cadw ffeil</translation>
    </message>
    <message>
        <location filename="window.py" line="821"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Methu â chadw i ffeil gan ei bod yn darllen yn unig</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>Export document to ODT</source>
        <translation>Allforio dogfen i ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Ffeiliau testun OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Ffeiliau HTML (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>Export document to PDF</source>
        <translation>Allforio dogfen i PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>PDF files (*.pdf)</source>
        <translation>Ffeiliau PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="908"/>
        <source>Print document</source>
        <translation>Argraffu dogfen</translation>
    </message>
    <message>
        <location filename="window.py" line="932"/>
        <source>Export document</source>
        <translation>Allforio dogfen</translation>
    </message>
    <message>
        <location filename="window.py" line="953"/>
        <source>Failed to execute the command:</source>
        <translation>Methwyd â rhedeg y gorchymyn:</translation>
    </message>
    <message>
        <location filename="window.py" line="1064"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Cafodd y ddogfen hon ei haddasu.
Ydych chi am gadw&apos;ch newidiadau?</translation>
    </message>
    <message>
        <location filename="window.py" line="1089"/>
        <source>HTML code</source>
        <translation>Cod HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Golygydd syml ond pwerus ar gyfer Markdown a reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Awdur: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Website</source>
        <translation>Gwefan</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Markdown syntax</source>
        <translation>Cystrawen markdown</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>reStructuredText syntax</source>
        <translation>Cystrawen reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="281"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="553"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="776"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1044"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="107"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="140"/>
        <source>Table editing mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>FakeVim mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1028"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1035"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="117"/>
        <source>Change editor font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="119"/>
        <source>Change preview font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="192"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="987"/>
        <source>Alt text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>Link text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
